# Wooldridge - Introductory Econometrics #
# Capitulo 1 - Exercicios de Computador - Resolucao #

# Disciplina: Introducao aos Modelos Lineares (POP|UFMG)
# Professor: Gilvan Guedes (Cedeplar | UFMG)
# Monitor: Otavio Miranda (Estatistica | UFMG)

rm(list=ls(all=T)) # limpando os objetos do ambiente

if(!require(wooldridge)){install.packages("wooldridge");library("wooldridge")}

### C1 ------------------

data("wage1") # carregando os dados
?wage1 # obtendo informacao sobre o banco de dados

# 1) Find the average education level in the sample. What are the lowest and 
# highest years of education?
names(wage1) # listando os nomes das variaveis
labels(wage1) # listando os rotulos das variaveis

mean(wage1$educ) # 12.6
mean(wage1[,"educ"])
round(mean(wage1$educ),digits=1) # Se quiser arredondar para 1 casa decimal
summary(wage1$educ) # Encontrando minimo e maximo
min(wage1$educ);max(wage1$educ) # modo alternativo
table(wage1$educ[wage1$educ==min(wage1$educ)]) # numero de pessoas com 0 (min)
table(wage1$educ[wage1$educ==max(wage1$educ)]) # numero de pessoas com 18 (max)

# 2) Find the average hourly wage in the sample. Does it seem high or low?

round(mean(wage1$wage),digits=2) # 5.9 dolares

# 3) The wage data are reported in 1976 dollars. Using the Internet or a printed
# source, find the Consumer Price Index (CPI) for the years 1976 and 2013.

# usando a T-60 do CPI do 2004 Economic Report of the President (base = 1982-84):
# CPI (1976) = 56.9
# CPI (2013) = 233
round((0.965*0.996*1.039)^(1/3),digits=2)


# 4) Use the CPI values from part (3) to find the average hourly wage in 2013
# dollars. Now does the average hourly wage seem reasonable?

round(mean(wage1$wage)*233/56.9,digits=2) # 24.14 dolares


# 5) How many women are in the sample? How many men?

sum(wage1$female) # 252 mulheres e 274 homens
table(wage1$female) # Maneira alternativa.

### C2 ------------------

data("bwght")
?bwght

# 1) How many women are in the sample, and how many report smoking during pregnancy?

dim(bwght)[1] # 1388 mulheres na amostra (numero de linhas).
nrow(bwght) # forma alternativa
sum(bwght$cigs > 0) # 212 mulheres fumantes na gravidez

# 2) What is the average number of cigarettes smoked per day? Is the average a
# good measure of the "typical" woman in this case? Explain.

round(mean(bwght$cigs),digits=2) # 2.09 cigarros por dia
# Nao, porque inclui as mulheres que nao fumaram (85% da amostra). Veja que
# a mediana de cigarros por dia = 0.
median(bwght$cigs)
quantile(bwght$cigs,0.84)
cbind(table(bwght$cigs),round(prop.table(table(bwght$cigs)),digits=2))
bwght$nonsmoke=ifelse(bwght$cigs==0,1,0)
round(prop.table(table(bwght$nonsmoke)),2) # 85% nao fumante
bwght=bwght[,-bwght$nonsmoke] # apagando coluna

# 3) Among women who smoked during pregnancy, what is the average number of
# cigarettes smoked per day? How does this compare with your answer from part
# (ii), and why?

mean(bwght[bwght$cigs > 0, "cigs"]) # 13.67 cigarros em media
mean(bwght$cigs[bwght$cigs>0]) # forma alternativa

# 4) Find the average of fatheduc in the sample. Why are only 1,192 observations
# used to compute this average?

table(bwght$fatheduc, useNA = "ifany") # 196 missings
mean(bwght$fatheduc, na.rm = T) # exclui os missings para o calculo
mean(na.omit(bwght$fatheduc)) # forma alternativa
# R: Pois ha 196 missings (NA)

# 5) Report the average family income and its standard deviation in dollars.

mean(bwght$faminc*1000) # US$29,026.66
sd(bwght$faminc*1000) # US$18,739.28


### C3 ------------------

data("meap01")
?meap01

# 1) Find the largest and smallest values of math4. Does the range make sense?
# Explain.

summary(meap01$math4) # nao tem missing
min(meap01$math4) # 0
max(meap01$math4) # 100

# 2) How many schools have a perfect pass rate on the math test? 

sum(meap01$math4 == 100) # 38 escolas

# What percentage is this of the total sample?

mean(meap01$math4 == 100)*100 # 2.08%

# 3) How many schools have math pass rates of exactly 50%?

sum(meap01$math4 == 50) # 17 escolas

# 4) Compare the average pass rates for the math and reading scores. Which test
# is harder to pass?

mean(meap01$math4) # 71.91
mean(meap01$read4) # 60.06
# Mais dificil de passar em matematica

# 5) Find the correlation between math4 and read4. 

cor(meap01$math4, meap01$read4)

# What do you conclude? 
# R: Correlacao linear proxima de 1, indicando relacao positiva
# entre os resultados das disciplinas. Ou seja, maiores percentuais de aprovacao
# em math4 estao associados a percentuais maiores em read4.

# 6) The variable exppp is expenditure per pupil. Find the average of exppp
# along with its standard deviation. Would you say there is wide variation in
# per pupil spending?

summary(meap01$exppp) # checando presenca de missing
mean(meap01$exppp) # US$5,194.87
sd(meap01$exppp) # US$1,091.89.
sd(meap01$exppp)/mean(meap01$exppp) # coeficiente de variacao

#7) Suppose School A spends $6,000 per student and School B spends $5,500 per
#student. By what percentage does School A's spending exceed School B's? Compare
#this to 100 * [log(6,000) - log(5,500)] , which is the approximation percentage
#difference based on the difference in the natural logs. (See Section A.4 in
#Appendix A.)

100 * (6000 / 5500) - 100
100 * (log(6000) - log(5500))

### C4 ------------------

data("jtrain2")
?jtrain2

# 1) Use the indicator variable train to determine the fraction of men receiving
# job training.

mean(jtrain2$train)*100 # 1 if assigned to job training. 41.6%

# 2) The variable re78 is earnings from 1978, measured in thousands of 1982
# dollars. Find the averages of re78 for the sample of men receiving job
# training and the sample not receiving job training. Is the difference
# economically large?

mean(jtrain2[jtrain2$train == 1, "re78"]) # men receiving job training.
mean(jtrain2[jtrain2$train == 0, "re78"]) # not receiving job training.
# A difference of almost US$1,800.00. It is a lot! In %, this would be:
with(jtrain2,(mean(re78[train==1])/mean(re78[train==0])-1)*100) # 40% higher

# 3) The variable unem78 is an indicator of whether a man is unemployed or not
# in 1978. What fraction of the men who received job training are unemployed?
# What about for men who did not receive job training? Comment on the
# difference.

mean(jtrain2[jtrain2$train == 1, "unem78"])
mean(jtrain2[jtrain2$train == 0, "unem78"])
with(jtrain2,(mean(unem78[train==0])/mean(unem78[train==1])-1)*100) # 40% higher

# R: O grupo de homens que nao receberam tratamento apresentam maior percentual
# de desemprego (45.5% maior)

# 4) From parts (ii) and (iii), does it appear that the job training program
# was effective? What would make our conclusions more convincing?

# R: Sim, homens que receberam treinamento tiveram em media maiores "salarios"
# e menor percentual de desemprego. Para melhor analise, poderiamos
# recorrer a testes de hipoteses para diferenca de medias.

t.test(jtrain2$re78[jtrain2$train==1],
       jtrain2$re78[jtrain2$train==0],
       mu=0,paired=FALSE,var.equal=FALSE)

t.test(jtrain2$unem78[jtrain2$train==1],
       jtrain2$unem78[jtrain2$train==0],
       mu=0,paired=FALSE,var.equal=FALSE)

# O teste, por exemplo, mostra que a diferença de salário real e de desemprego
# entre quem fez ou nao treinamento foi estatisticamente diferente de zero.


### C5 ------------------

data("fertil2")
?fertil2

attach(fertil2) # forma de nao precisar ficar escrevendo toda hora o nome do
# data.frame

# 1) Find the smallest and largest values of children in the sample. What is the
# average of children?

summary(children)
min(children) # 0 child
max(children) # 13 children
mean(children) #2.3 children

# 2) What percentage of women have electricity in the home?

mean(electric, na.rm = T) # 14%

# 3) Compute the average of children for those without electricity and do the
# same for those with electricity. Comment on what you find.

mean(fertil2[electric == 0, "children"], na.rm = T)
mean(fertil2[electric == 1, "children"], na.rm = T)

t.test(na.omit(fertil2[electric == 0, "children"]),
       na.omit(fertil2[electric == 1, "children"]),
       mu=0,paired=FALSE,var.equal=FALSE)

# R: Em media, mulheres cujo casa nao possui energia eletrica possuem mais
# filhos vivos.

# 4) From part (iii), can you infer that having electricity "causes" women to
# have fewer children? Explain.

# R: Nao. Temos apenas uma medida pontual da diferenca de medias e nao estamos
# considerando se os 2 grupos comparados sao homogeneos com respeito as demais
# variaveis. Portanto, devemos investigar se a diferenca e significativa e
# analisar a influencia de outros aspectos para verificar se e plausivel essa
# afirmacao.

detach(fertil2)

### C6 ------------------

data(package='wooldridge') # checando todos os bancos no pacote
                           # nao possui o countymuders. Tera que ser importado.

# Lendo o banco 'countymurders' diretamente de um arquivo txt
countymurders <- read.table(file = "/Users/grguedes/Dropbox/UFMG/IML2018/Conjunto_de_dados/Data Sets- R/countymurders.txt",
                            sep = ",",
                            header = TRUE)

# 1) Use only the year 1996. How many counties are there in the data set? 

dados_96 <- subset(countymurders, subset = year == 1996)
length(unique(dados_96$countyid)) # 2,197 counties (condados)

# Of these, how many have zero murders?

sum(dados_96$murders == 0) # Funciona pois cada linha representa um county.
length(unique(dados_96[dados_96$murders == 0, "countyid"])) # Alternativa mais geral
# Reposta: 1,051 counties sem assassinato.

# What percentage of counties have zero executions? (Remember, use only the 1996
# data.)

table(dados_96$execs)
mean(dados_96$execs == 0) # forma direta de pegar o percentual (98.6%)

# 2) What is the largest number of murders? What is the largest number of
# executions? Why is the average number of executions so small?

max(dados_96$murders)
max(dados_96$execs)
mean(dados_96$execs)

par(mfrow=c(1,1))
hist(dados_96$execs)

# Grafico incluindo os zeros
plot(density(dados_96$execs),main="Kernel Density") # Veja que a massa de
# probabilidade esta concentrada em torno de 0, e maximo e 3.
polygon(density(dados_96$execs), col="red", border="blue")

# Grafico excluindo os zeros
plot(density(dados_96$execs[dados_96$execs>0]),main="Kernel Density") # Veja que a massa de
    # probabilidade esta concentrada em torno de 0, e maximo e 3.
polygon(density(dados_96$execs[dados_96$execs>0]), col="red", border="blue")

# 3) Compute the correlation coefficient between murders and execs and describe
# what you find.

cor(dados_96$murders, dados_96$execs) # 0.21

#R: Correlacao positiva mas proxima de 0, indicanto fraca associacao linear
# entre numero de assassinatos e execucoes por pena de morte.

# 4) You should have computed a positive correlation in part (iii). Do you think
# that more executions cause more murders to occur? What might explain the
# positive correlation?

# Nao. A correlacao observada e fraca. Alem disso, correlacao nao e uma medida
# de causalidade. Outros estudos deveriam ser feitos para tal afirmacao.
# Ademais, essa correlacao e apenas linear. Vejamos a distribuicao bivariada
# dos dados de assassinato e execucao:
plot(dados_96$murders,dados_96$execs)


### C7 ------------------

data("alcohol")
?alcohol # tem outro banco com mesmo nome, de outro pacote
?wooldridge::alcohol

# 1) What is percentage of the men in the sample report abusing alcohol? What is the
#employment rate?

mean(alcohol$abuse)*100 # 9.9%
mean(alcohol$employ)*100 # 89.8%

# 2) Consider the group of men who abuse alcohol. What is the employment rate?

mean(alcohol[alcohol$abuse == 1, "employ"])*100 # 87.3%

# 3) What is the employment rate for the group of men who do not abuse alcohol?

mean(alcohol[alcohol$abuse == 0, "employ"])*100 # 90.1%

# 4) Discuss the difference in your answers to parts (ii) and (iii). Does this
# allow you to conclude that alcohol abuse causes unemployment?

# R: Nao. Temos apenas uma medida pontual da diferenca de medias e nao estamos
# considerando se os 2 grupos comparados sao homogeneos com respeito as demais
# variaveis. Portanto, devemos investigar se a diferenca e significativa e
# analisar a influencia de outros aspectos para verificar se e plausivel essa
# afirmacao.